/* sketch weerstation_2c
 * Temperatuur, luchtvochtigheid en luchtdruk meten en de meetwaarde op het LCD plaatsen
 * I2C voor LCD en BMP 280 sensor
 *
 * LCD GND en BMP GND --> GND Arduino
 * LCD VCC en BMP Vin --> 5V  Arduino
 * LCD SDA en BMP SDI --> A4  Arduino
 * LCD SCL en BMP SCK --> A5  Arduino
 * 
 * I2C aansluitingen van Arduino Uno:A4 (SDA), A5 (SCL)
 * 
 * DHT22 voor temperatuur en vochtigheid 
 * ARDUINO pen 9 voor data van DHT22
 */

#include <Wire.h>               // Bibliotheek voor communicatie met I2C 
#include <LiquidCrystal_I2C.h>  // Bibliotheek voor het I2C LCD scherm
#include <Adafruit_BMP280.h>    // Bibliotheek voor de BMP 280 sensor
#include <DHT.h>                // Bibliotheek voor de DHT sensor

LiquidCrystal_I2C lcd(0x27, 20, 4); // start LCD scherm en lcd is gebruiksnaam
Adafruit_BMP280 bmp;                // bmp is nu de gebruiksnaam voor de druk sensor
DHT sensor_dht(9, DHT22);           // onze sensor heet nu: sensor_dht

float luchtdruk, temperatuur, vochtigheid; // variabelen

void setup() {
  lcd.init();                  // initialisatie van het LCD scherm
  lcd.backlight();             // zet het backlight aan
  bmp.begin();                 // start de bmp sensor
  sensor_dht.begin();          // start de dht sensor 
}
 
void loop() {
  delay(2000);
  lcd.clear();                 // wis het scherm
  delay(500);
  //lees de temperatuur, vochtigheid en luchtdruk uit en bewaar die in de variabelen
  temperatuur = sensor_dht.readTemperature();
  vochtigheid = sensor_dht.readHumidity();
  luchtdruk = bmp.readPressure()/100.0;                
  lcd.setCursor(0, 0);         // zet de cursor op positie 1, regel 1
  lcd.print ("Temp : "); lcd.print(temperatuur,1); lcd.print (" C ");
  delay(500);
  lcd.setCursor(0, 1);         // zet de cursor op positie 1, regel 2
  lcd.print ("Vocht: "); lcd.print(vochtigheid,1); lcd.print (" % ");
  delay(500);
  lcd.setCursor(0, 2);         // zet de cursor op positie 1, regel 3
  lcd.print("Luchtdruk "); lcd.print (luchtdruk,1); lcd.print (" hPa");
  delay(500);
  lcd.setCursor(0, 3);         // zet de cursor op positie 1, regel 4
  lcd.print("Regel 4");        // schrijf op scherm
  delay(1000);
}
